@@ -1,7 +1,7 @@
 import uuid, json
 
 from rest_framework.response import Response
-from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, DecryptingSenderKey, Party, LimitedAccessToken
+from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, DecryptingSenderKey, Party
 from django.db.models import Q
 from firebase_admin import db
 from django.conf import settings
